<?php
namespace FM\Controller;

use FM\Controller\FMCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use FM\Service\UsuariosService;

class UsuariosController extends FMCrud{
    protected $dataSourceName = 'fcm_checklistagend';
    protected $UsuariosService;
   
    public function __construct($crudService, $environment, UsuariosService $UsuariosService) {
        parent::__construct($crudService, $environment);
        $this->UsuariosService = $UsuariosService;
    }

    // Busca uma lista de usuários, todas as informações 
    public function getUsersController(DTO\Request $request, DTO\Response $response) {
        $params = $request->getParameters();

        $var = $this->UsuariosService->getUsersService($params);
        $dtsVal = new DataSet('info', $var);
        $response->addDataSet($dtsVal);
    }

    // Busca uma lista de usuários, só nome e id
    public function usersListController(DTO\Request $request, DTO\Response $response) {
        $var = $this->UsuariosService->usersListService();
        $dtsVal = new DataSet('info', $var);
        $response->addDataSet($dtsVal);
    }
    
    public function createUserController(DTO\Request $request, DTO\Response $response) {
        
        $params = $request->getParameters();

        $nmfuncionario = $params['userInfos']['NMFUNCIONARIO'];
        $nrperfilacesso = $params['userInfos']['NRPERFILACESSO'];
        $nrcpffuncionario = $params['userInfos']['NRCPFFUNCIONARIO'];
        $nrrgfuncionario = $params['userInfos']['NRRGFUNCIONARIO'];
        $dsemailfuncionario = $params['userInfos']['DSEMAILFUNCIONARIO'];
        $nrtelfuncionario = $params['userInfos']['NRTELFUNCIONARIO'];
        $dssenhafunc = $params['userInfos']['DSSENHAFUNC'];
        $nrsetor = $params['userInfos']['NRSETOR'];
        
        $var = $this->UsuariosService->createUserService($nmfuncionario, $nrperfilacesso, $nrcpffuncionario, $nrrgfuncionario, $dsemailfuncionario, $nrtelfuncionario, $dssenhafunc, $nrsetor);
        $dtsVal = new DataSet('info', $var);
        $response->addDataSet($dtsVal);
    }
    
    // Busca as informações de um usuário específico
    public function getUserInfosController(DTO\Request $request, DTO\Response $response) {
        
        $params = $request->getParameters();
        
        $nrfuncionario = $params['params']['NRFUNCIONARIO'];
        
        $var = $this->UsuariosService->getUserInfosService($nrfuncionario);
        $dtsVal = new DataSet('info', $var);
        $response->addDataSet($dtsVal);
    }
    
    public function updateUserController(DTO\Request $request, DTO\Response $response) {
        
        $params = $request->getParameters();

        $nrfuncionario = $params['params']['NRFUNCIONARIO'];
        $nmfuncionario = $params['params']['NMFUNCIONARIO'];
        $nrperfilacesso = $params['params']['NRPERFILACESSO'];
        $nrcpffuncionario = $params['params']['NRCPFFUNCIONARIO'];
        $nrrgfuncionario = $params['params']['NRRGFUNCIONARIO'];
        $dsemailfuncionario = $params['params']['DSEMAILFUNCIONARIO'];
        $nrtelfuncionario = $params['params']['NRTELFUNCIONARIO'];
        $dssenhafunc = $params['params']['DSSENHAFUNC'];
        $nrsetor = $params['params']['NRSETOR'];
        $relacfuncperfacess = $params['params']['RELACFUNCPERFACESS'];
        $nrrelacfuncsetor = $params['params']['NRRELACFUNCSETOR'];
        
        $var = $this->UsuariosService->updateUserService($nrfuncionario, $nmfuncionario, $nrperfilacesso, $nrcpffuncionario, $nrrgfuncionario, $dsemailfuncionario, $nrtelfuncionario, $dssenhafunc, $nrsetor, $relacfuncperfacess, $nrrelacfuncsetor);
        $dtsVal = new DataSet('info', $var);
        $response->addDataSet($dtsVal);
    }
    
    public function deleteUserController(DTO\Request $request, DTO\Response $response) {
        $params = $request->getParameters();

        $var = $this->UsuariosService->deleteUsersService($params);
        $dtsVal = new DataSet('info', array("resultado" => $var));
        $response->addDataSet($dtsVal);
    }
}
?>